==> slapos.cookbook-0.56-dev.tar.gz: slapos.cookbook-0.56-dev/slapos/recipe/generatepassword.py <==
##############################################################################
#
# Copyright (c) 2012 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
import random
import os
import binascii

from slapos.recipe.librecipe import GenericBaseRecipe

class Recipe(GenericBaseRecipe):

  def __init__(self, buildout, name, options):
    if os.path.exists(options['storage-path']):
      open_file = open(options['storage-path'], 'r')
      options['passwd'] = open_file.read()
      open_file.close()

    if options.get('passwd', '') == '':
      options['passwd'] = binascii.hexlify(os.urandom(
                            int(options.get('bytes', '24'))))
    return GenericBaseRecipe.__init__(self, buildout, name, options)

  def install(self):
    open_file = open(self.options['storage-path'], 'w')
    open_file.write(self.options['passwd'])
    open_file.close()
    return [self.options['storage-path']]

==> slapos.cookbook-0.75.0.tar.gz: slapos.cookbook-0.75.0/slapos/recipe/generatepassword.py <==
# vim: set et sts=2:
##############################################################################
#
# Copyright (c) 2012 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import binascii
import os

from slapos.recipe.librecipe import GenericBaseRecipe


class Recipe(GenericBaseRecipe):

  def __init__(self, buildout, name, options):
    if os.path.exists(options['storage-path']):
      open_file = open(options['storage-path'], 'r')
      options['passwd'] = open_file.read()
      open_file.close()

    if options.get('passwd', '') == '':
      options['passwd'] = binascii.hexlify(os.urandom(
                            int(options.get('bytes', '24'))))
    return GenericBaseRecipe.__init__(self, buildout, name, options)

  def install(self):
    with open(self.options['storage-path'], 'w') as fout:
      fout.write(self.options['passwd'])
    return [self.options['storage-path']]
